// -*- Mode: C++; -*-
#ifndef __string_res_h
#define __string_res_h

#include <utility>
#include <string>

typedef std::pair<unsigned int,std::string> string_res;

class CStringRes
{
protected:
    static const string_res res_array[];
    std::string last_message;
public:
    CStringRes(){last_message = "";}
    ~CStringRes(){}
    static const char*get_string(unsigned int id);
};

// for an easier use
#define GET_TEXT(x) i18n(CStringRes::get_string(x))
#endif
